@@ -1,6 +1,5 @@
 package NOLookup::BrregDifi::DataLookup;
 
-use warnings;
 use strict;
 use base qw(Class::Accessor::Chained); ## Provides a new() method
 use POSIX qw(locale_h);
@@ -11,6 +10,8 @@ use URI::Encode qw(uri_encode);
 use Data::Dumper;
 $Data::Dumper::Indent=1;
 
+our $VERSION = 1.01;
+
 my $BRREG_TIMEOUT = 60; # secs (default is 180 secs but we want shorter time).
 
 # The query can be a name, or an orgnumber.
@@ -62,7 +63,6 @@ sub lookup_orgno {
     ##
     # Use the orgno as key to brreg.
     # Match is only found if number does exist.
-    $self->size(0);
     $self->_lookup_org_entries("$BRREG_ORGNO=$orgno");
 }
 
@@ -144,20 +144,7 @@ sub _lookup_org_entries {
 	return $self;
     }
 
-    my $json;
-    {
-	local $@; # protect existing $@
-	eval {
-	    $json = decode_json($mech->content(format=>'text'));
-	};
-	if ($@) {
-	    # Some error
-	    $self->status("Invalid response");
-	    $self->error(1);
-	    $self->next_page(undef);
-	    return $self;
-	}
-    }
+    my $json = decode_json($mech->text);
 
     if ($json) {
 	$self->raw_json_decoded($json);
@@ -312,7 +299,8 @@ Please also see the SUPPORT file in the distribution.
 
 =head1 SEE ALSO
 
-http://hotell.difi.no/?dataset=brreg/enhetsregisteret
+http://www.brreg.no
+http://data.brreg.no/oppslag/enhetsregisteret/enheter.xhtml
 
 =head1 AUTHOR
 
@@ -320,7 +308,7 @@ Trond Haugen, E<lt>(nospam)info(at)norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2017 Trond Haugen <(nospam)info(at)norid.no>.
+Copyright (c) 2016 Trond Haugen <(nospam)info(at)norid.no>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
