@@ -2,7 +2,7 @@ package NOLookup::DAS::DASLookup;
 
 use strict;
 use warnings;
-use IO::Socket::INET6;
+use IO::Socket;
 use Encode;
 
 use vars qw(@ISA @EXPORT_OK);
@@ -16,6 +16,8 @@ use vars qw(@ISA @EXPORT_OK);
                   $DAS_LOOKUP_ERR_OTHER
 /;
 
+our $VERSION = 1.01;
+
 # Error codes returned fom the DASLookup module
 # Ref. the Norid API definition at
 #  https://www.norid.no/en/registrar/system/dokumentasjon/whoisdas-grensesnitt/
@@ -70,7 +72,7 @@ sub lookup {
 
     my ($line, $text);
 
-    my $sock = IO::Socket::INET6->new (
+    my $sock = IO::Socket::INET->new (
 	PeerAddr => $das_server,
 	PeerPort => $das_port,
 	Proto    => 'tcp',
@@ -138,10 +140,6 @@ sub lookup {
     return $self;
 }
 
-=pod
-
-=encoding ISO-8859-1
-
 =head1 NAME
 
 NOLookup::DAS::DASLookup - Lookup DAS data from Norid.
@@ -194,16 +192,15 @@ See SYNOPSIS.
 
 =head1 SEE ALSO
 
-L<https://www.norid.no/en>
-L<https://teknisk.norid.no/en/integrere-mot-norid/whois>
+L<http://www.norid.no>
 
 =head1 AUTHOR
 
-Trond Haugen, E<lt>(nospam)info(at)norid.noE<gt>
+Trond Haugen  C<trond.haugen@uninett.no>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2017 Trond Haugen <(nospam)info(at)norid.no>.
+Copyright (c) 2016 Trond Haugen <(nospam)info(at)norid.no>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
