@@ -1,7 +1,5 @@
-
 package NOLookup::Patent::DataLookup;
 
-use warnings;
 use strict;
 use base qw(Class::Accessor::Chained); ## Provides a new() method
 use POSIX qw(locale_h);
@@ -12,16 +10,13 @@ use URI::Encode qw(uri_encode);
 use Data::Dumper;
 $Data::Dumper::Indent=1;
 
+our $VERSION = 1.01;
+
 my $PATENT_TIMEOUT = 60; # secs (default is 180 secs but we want shorter time).
 
-####
-# API ref: https://ws.patentstyret.no/search/metadata
-#          https://ws.patentstyret.no/search/json/metadata?op=Search
-###
-
 # Free text search gives too many hits, so use the trademark-text-search
-my $PATENT_SEARCH = "https://ws.patentstyret.no/search/json/reply/search/trademark/?trademarktext";
-my $PATENT_ID     = "https://ws.patentstyret.no/search/json/reply/DetailedInfoRequest/trademark/detailedinfo/?ApplicationNumber";
+my $PATENT_SEARCH = "http://ws.patentstyret.no/search/json/reply/search/trademark/?trademarktext";
+my $PATENT_ID     = "http://ws.patentstyret.no/search/json/reply/DetailedInfoRequest/trademark/detailedinfo/?ApplicationNumber";
 
 my @module_methods = qw /
 
@@ -47,14 +42,18 @@ __PACKAGE__->mk_accessors(
 ######## L o o k u p
 
 sub lookup_tm_text {
-    my ($self, $tm_text, $max_no_pages, $page_ix, $page_sz) = @_;
+    my ($self, $tm_text, $max_no_pages, $page_ix) = @_;
 
     die "mandatory parameter 'tm_text' not specified" unless ($tm_text);
 
     my $max_pg_to_fetch = $max_no_pages   || 10;
     my $pg_ix           = $page_ix        || 1;
-    my $max_pg_elems    = $page_sz        || 100;
 
+    # Use a fixed 100 on number of elements on page, to be consistent
+    # with brreg_difi API, which does not support setting of this
+    # parameter.
+    my $max_pg_elems = 100;
+    
     my $tmt_e = uri_encode($tm_text, {encode_reserved => 1});
 
     # set size and total size so we get the first lookup
@@ -92,7 +91,7 @@ sub lookup_tm_applid {
 sub _lookup_tm_entries {
     my ($self, $URL) = @_;
 
-    print STDERR "URL: $URL\n" if ($self->{debug});
+    #print STDERR "URL: $URL\n";
     
     my $mech = WWW::Mechanize->new(
         timeout => $PATENT_TIMEOUT,
@@ -104,32 +103,17 @@ sub _lookup_tm_entries {
     unless ($mech->success) {
 	$self->status($resp->status_line);
 	$self->error(1);
-	# If a content exists, try a decode of it before return is done
-	return $self unless ($mech->content);
-    }
-    
-    my $json;
-    {
-	local $@; # protect existing $@
-	eval {
-	    $json = decode_json($mech->content(format=>'text'));
-	};
-	if ($@) {
-	    # Some error
-	    $self->status("Invalid response");
-	    $self->error(1);
-	    $self->next_page(undef);
-	    return $self;
-	}
+	return $self;
     }
 
+    my $json = decode_json($mech->text);
+
+    #print STDERR "URL: $URL\n";
+    #print "JSON: ", Dumper $json, "\n";
+    
     if ($json) {
 	$self->raw_json_decoded($json);
-
-	# From above: For errors we now have a decoded content, time to return.
-	#print STDERR "TM lookup error: ", Dumper $mech;
-	return $self if ($self->error);
-
+	
 	# Map the json data structure to 
 	# internal entry objects
 	my $eo = NOLookup::Patent::Entry->new;
@@ -145,8 +129,6 @@ sub _lookup_tm_entries {
 	    push @{$self->{data}}, @$entries;
 	    $self->size($self->size + $eo->result_count);
 	    $self->total_size($eo->total_result_count);
-	} else {
-	    $self->total_size(0);
 	}
     }
     return $self;
@@ -184,7 +166,6 @@ Mandatory parameters are:
 Optional parameters are:
    $max_no_pages: max. number of pages to return, default 10.
    $page_ix     : index to the first page to fetch, default 1.
-   $page_sz     : number of entries per page, default 100.
 
 Returns 0 entries if none found.
 
@@ -249,7 +230,6 @@ Please also see the SUPPORT file in the distribution.
 C<NOLookup::Patent::Entry>
 L<http://www.patentstyret.no>
 L<http://ws.patentstyret.no/search>
-L<https://dbsearch2.patentstyret.no/AdvancedSearch.aspx?Category=Mark>
 
 =head1 AUTHOR
 
@@ -257,7 +237,7 @@ Trond Haugen, E<lt>(nospam)info(at)norid.noE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2017 Trond Haugen <(nospam)info(at)norid.no>.
+Copyright (c) 2016-2017 Trond Haugen <(nospam)info(at)norid.no>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
